@@ -25,7 +25,12 @@ document.gtwidgets = {
         });
     },
     DateRangeInput: function (instance) {
-        instance.daterangepicker(load_date_range(instance));
+        format = instance.attr('data-format')
+        instance.each((i,element)=>{
+        $(element).daterangepicker(load_date_range(instance), (from_date, to_date) => {
+            $(element).val(from_date.format(format) + ' - ' + to_date.format(format));
+        });
+    });
     },
 
     GridSlider: function (instance) {
@@ -49,15 +54,6 @@ document.gtwidgets = {
     DateRangeTimeInput: function (instance) {
         instance.daterangepicker(load_datetime_range(instance));
     },
-    TreeSelectWithAdd: function (instance) {
-        instance.select2({ templateResult: decore_select2 });
-    },
-    TreeSelectMultiple: function (instance) {
-        instance.select2({ templateResult: decore_select2 });
-    },
-    TreeSelectMultipleWithAdd: function (instance) {
-        instance.select2({ templateResult: decore_select2 });
-    },
     DateTimeInput: function (instance) {
         instance.datetimepicker({format : instance.data('format') });// "YYYY-MM-DD HH:mm"
     },
@@ -117,9 +113,12 @@ document.gtwidgets = {
     },
     TreeSelectMultipleWithAdd: function (instance) {
         instance.addselectwidget();
+        instance.select2({ templateResult: decore_select2 });
     },
     TreeSelectWithAdd: function (instance) {
         instance.addselectwidget();
+        instance.select2({ templateResult: decore_select2 });
+
     },
     FileInput: function (instance) {
         instance.fileuploadwidget();
